==> huff-1.1.2.tar.gz: huff-1.1.2/README.md <==
# huff: Huff Model Market Area Analysis

## Author

Thomas Wieland [ORCID](https://orcid.org/0000-0001-5168-9846) [EMail](mailto:geowieland@googlemail.com) 

See the /tests directory for usage examples of most of the included functions.


## Features

- **Huff Model**: 
  - Defining origins and destinations with weightings
  - Creating interaction matrix from origins and destinations
  - Calculating basic Huff Model
- **Multiplicative Competitive Interaction Model**: 
  - Log-centering transformation
- **OpenRouteService Client** (Tools via API): 
  - Creating transport costs matrix from origins and destinations
  - Creating isochrones from destinations

Attribution of OpenRouteService:
© openrouteservice.org by HeiGIT | Map data © OpenStreetMap contributors

Visit https://openrouteservice.org/

## Literature
  - Huff DL (1962) *Determination of Intra-Urban Retail Trade Areas*.
  - Huff DL (1964) Defining and estimating a trading area. *Journal of Marketing* 28(4): 34–38. [10.2307/1249154](https://doi.org/10.2307/1249154)
  - Huff DL, McCallum BM (2008) Calibrating the Huff Model using ArcGIS Business Analyst. ESRI White Paper, September 2008. https://www.esri.com/library/whitepapers/pdfs/calibrating-huff-model.pdf. 
  - De Beule M, Van den Poel D, Van de Weghe N (2014) An extended Huff-model for robustly benchmarking and predicting retail network performance. *Applied Geography*,* 46(1): 80–89. [10.1016/j.apgeog.2013.09.026](https://doi.org/10.1016/j.apgeog.2013.09.026) 
  - Nakanishi M, Cooper LG (1974) Parameter estimation for a Multiplicative Competitive Interaction Model: Least squares approach. *Journal of Marketing Research* 11(3): 303–311. [10.2307/3151146](https://doi.org/10.2307/3151146).
  - Wieland T (2017) Market Area Analysis for Retail and Service Locations with MCI. *R Journal* 9(1): 298-323. [10.32614/RJ-2017-020](https://doi.org/10.32614/RJ-2017-020)
  - Wieland T (2018) A Hurdle Model Approach of Store Choice and Market Area Analysis in Grocery Retailing. *Papers in Applied Geography* 4(4): 370-389. [10.1080/23754931.2018.1519458](https://doi.org/10.1080/23754931.2018.1519458)


## Installation

To install the package, use `pip`:

```bash
pip install huff

==> huff-1.2.0.tar.gz: huff-1.2.0/README.md <==
# huff: Huff Model Market Area Analysis

## Author

Thomas Wieland [ORCID](https://orcid.org/0000-0001-5168-9846) [EMail](mailto:geowieland@googlemail.com) 

See the /tests directory for usage examples of most of the included functions.


## Features

- **Huff Model**: 
  - Defining origins and destinations with weightings
  - Creating interaction matrix from origins and destinations
  - Calculating basic Huff Model
- **Multiplicative Competitive Interaction Model**: 
  - Log-centering transformation
  - Fitting MCI model with >= independent variables
- **OpenRouteService Client** (1) (Tools via API): 
  - Creating transport costs matrix from origins and destinations
  - Creating isochrones from destinations
- **Tools**: 
  - Loading own interaction matrix for analysis
  - GIS tools for preparing geodata

(1) Attribution of OpenRouteService:
© openrouteservice.org by HeiGIT | Map data © OpenStreetMap contributors | https://openrouteservice.org/

## Literature
  - Huff DL (1962) *Determination of Intra-Urban Retail Trade Areas*.
  - Huff DL (1964) Defining and estimating a trading area. *Journal of Marketing* 28(4): 34–38. [10.2307/1249154](https://doi.org/10.2307/1249154)
  - Huff DL, McCallum BM (2008) Calibrating the Huff Model using ArcGIS Business Analyst. ESRI White Paper, September 2008. https://www.esri.com/library/whitepapers/pdfs/calibrating-huff-model.pdf. 
  - De Beule M, Van den Poel D, Van de Weghe N (2014) An extended Huff-model for robustly benchmarking and predicting retail network performance. *Applied Geography*,* 46(1): 80–89. [10.1016/j.apgeog.2013.09.026](https://doi.org/10.1016/j.apgeog.2013.09.026) 
  - Nakanishi M, Cooper LG (1974) Parameter estimation for a Multiplicative Competitive Interaction Model: Least squares approach. *Journal of Marketing Research* 11(3): 303–311. [10.2307/3151146](https://doi.org/10.2307/3151146).
  - Wieland T (2017) Market Area Analysis for Retail and Service Locations with MCI. *R Journal* 9(1): 298-323. [10.32614/RJ-2017-020](https://doi.org/10.32614/RJ-2017-020)
  - Wieland T (2018) A Hurdle Model Approach of Store Choice and Market Area Analysis in Grocery Retailing. *Papers in Applied Geography* 4(4): 370-389. [10.1080/23754931.2018.1519458](https://doi.org/10.1080/23754931.2018.1519458)


## Installation

To install the package, use `pip`:

```bash
pip install huff
